var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { AjaxError } from "@snickerdoodlelabs/objects";
import axios from "axios";
import { injectable } from "inversify";
import { ResultAsync } from "neverthrow";
import fetchAdapter from "../implementations/FetchAdapter.js";
let AxiosAjaxUtils = class AxiosAjaxUtils {
    constructor() {
        // Browsers have XMLHttpRequest, node has the http object. Axios will use
        // the right one depending. But server workers have neither, and need to
        // use the fetch adapter.
        // These checks are a PITA
        if (typeof importScripts === "function") {
            this.instance = axios.create({
                adapter: fetchAdapter,
            });
        }
        else {
            this.instance = axios.create({});
        }
    }
    get(url, config) {
        return ResultAsync.fromPromise(this.instance.get(this.stripTrailingSlash(url.toString()), config), (e) => {
            const err = e;
            if (err.response != null) {
                return new AjaxError(`Error returned from GET ${url}, ${err.message}`, err.response.status, err);
            }
            return new AjaxError(`Unable to GET ${url}, ${err.message}`, 500, err);
        }).map((response) => {
            return response.data;
        });
    }
    post(url, data, config) {
        return ResultAsync.fromPromise(this.instance.post(this.stripTrailingSlash(url.toString()), data, config), (e) => {
            const err = e;
            if (err.response != null) {
                return new AjaxError(`Error returned from POST ${url}, ${err.message}`, err.response.status, err);
            }
            return new AjaxError(`Unable to POST ${url}, ${err.message}`, 500, err);
        }).map((response) => {
            return response.data;
        });
    }
    put(url, data, config) {
        return ResultAsync.fromPromise(this.instance.put(this.stripTrailingSlash(url.toString()), data, config), (e) => {
            const err = e;
            if (err.response != null) {
                return new AjaxError(`Error returned from PUT ${url}, ${err.message}`, err.response.status, err);
            }
            return new AjaxError(`Unable to PUT ${url}, ${err.message}`, 500, err);
        }).map((response) => {
            return response.data;
        });
    }
    delete(url, config) {
        return ResultAsync.fromPromise(this.instance.delete(this.stripTrailingSlash(url.toString()), config), (e) => {
            const err = e;
            if (err.response != null) {
                return new AjaxError(`Error returned from DELETE ${url}, ${err.message}`, err.response.status, err);
            }
            return new AjaxError(`Unable to DELETE ${url}, ${err.message}`, 500, err);
        }).map((response) => {
            return response.data;
        });
    }
    setDefaultToken(token) {
        this.instance.defaults.headers.common = {
            authorization: `Bearer ${token}`,
        };
    }
    stripTrailingSlash(url) {
        return url.endsWith("/") ? url.slice(0, -1) : url;
    }
};
AxiosAjaxUtils = __decorate([
    injectable(),
    __metadata("design:paramtypes", [])
], AxiosAjaxUtils);
export { AxiosAjaxUtils };
//# sourceMappingURL=AxiosAjaxUtils.js.map